summaryrefslogtreecommitdiff
path: root/drivers/dahdi/wctdm.c
diff options
context:
space:
mode:
authorKevin P. Fleming <kpfleming@digium.com>2008-05-22 11:35:33 +0000
committerKevin P. Fleming <kpfleming@digium.com>2008-05-22 11:35:33 +0000
commit49a66e309c5c7564027efa4cf823fac6b374a751 (patch)
tree567f6b5f8f853468c1ccc7396d387363ac0a8729 /drivers/dahdi/wctdm.c
parent796225defc1043e11fc7209e50a20cc896b350e7 (diff)
fix up all remaining references to zaptel/zapata (except for the ones in credits that need to be left alone)
git-svn-id: http://svn.asterisk.org/svn/dahdi/linux/trunk@4324 a0bf4364-ded3-4de4-8d8a-66a801d63aff
Diffstat (limited to 'drivers/dahdi/wctdm.c')
-rw-r--r--drivers/dahdi/wctdm.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/drivers/dahdi/wctdm.c b/drivers/dahdi/wctdm.c
index 970c939..601ae8a 100644
--- a/drivers/dahdi/wctdm.c
+++ b/drivers/dahdi/wctdm.c
@@ -1,5 +1,5 @@
/*
* Wilcard TDM400P TDM FXS/FXO Interface Driver for Zapata Telephony interface
*
* Written by Mark Spencer <markster@digium.com>
* Matthew Fredrickson <creslin@digium.com>
@@ -2036,7 +2036,7 @@ static int wctdm_initialize(struct wctdm *wc)
{
int x;
- /* Zapata stuff */
+ /* DAHDI stuff */
sprintf(wc->span.name, "WCTDM/%d", wc->pos);
snprintf(wc->span.desc, sizeof(wc->span.desc) - 1, "%s Board %d", wc->variety, wc->pos + 1);
snprintf(wc->span.location, sizeof(wc->span.location) - 1,
@@ -2068,7 +2068,7 @@ static int wctdm_initialize(struct wctdm *wc)
wc->span.pvt = wc;
if (dahdi_register(&wc->span, 0)) {
- printk("Unable to register span with zaptel\n");
+ printk("Unable to register span with DAHDI\n");
return -1;
}
return 0;
@@ -1,5 +1,5 @@
/*
- * Wilcard TDM400P TDM FXS/FXO Interface Driver for Zapata Telephony interface
+ * Wilcard TDM400P TDM FXS/FXO Interface Driver for DAHDI Telephony interface
*
* Written by Mark Spencer <markster@digium.com>